@@ -25,6 +25,7 @@ def generate_bootstrap_count_curves(
     plot_title='Count curve',
     plot_output_path='counts.png',
     test_ann=None,
+    bounds=None,
 ):
     with open(gt_ann) as fp:
         GT_ANN = json.load(fp)
@@ -34,13 +35,18 @@ def generate_bootstrap_count_curves(
 
     n_images = len(GT_ANN['images'])
 
-    fig, ax = plt.subplots(figsize=[20, 9])
+    fig, ax = plt.subplots(figsize=[27, 18])
     ins = ax.inset_axes([0.05, 0.05, 0.45, 0.4])
-    ins.set_xlim([0.8, 1.0])
     ins.set_xticks([.85, .9, .95], [.85, .9, .95], fontsize=30)
     ins.yaxis.tick_right()
     ins.xaxis.tick_top()
 
+    if bounds is not None:
+        _, x_max, _, _ = bounds
+        ins.set_xlim([.8, x_max])
+    else:
+        ins.set_xlim([.8, 1.0])
+
     collected_rocs = {'precision': {}, 'recall': {}}
 
     _, non_bootstrap_rec = generate_count_curve(
@@ -134,6 +140,9 @@ def generate_bootstrap_count_curves(
             non_bootstrap_rec[cat_id],
         )
 
+        if bounds is not None:
+            min_rec, max_rec = bounds[0], bounds[1]
+
         x_range = np.linspace(min_rec, max_rec, n_sample_points, endpoint=True)
 
         rocs = []
@@ -199,10 +208,6 @@ def generate_bootstrap_count_curves(
             alpha=.2,
         )
 
-        for rec, prec in zip(all_rec, all_prec):
-            ax.plot(rec, prec, 'r-', alpha=.1)
-            ins.plot(rec, prec, 'r-', alpha=.1)
-
         if test_ann is not None:
             for t_ann, c in zip(test_ann, COLORS):
                 t_ann, label = t_ann
@@ -231,20 +236,27 @@ def generate_bootstrap_count_curves(
                 )
                 ax.hlines(
                     y=_prec_accuracy[cat_id][0],
-                    xmin=np.min(all_rec),
-                    xmax=np.max(all_rec),
+                    xmin=.6,
+                    xmax=1.,
                     linestyles='dashed',
                     colors=c,
                 )
-                ax.text(
-                    x=min_rec, y=_prec_accuracy[cat_id][0] - 0.035,
-                    s=f' R = {np.round(_rec_per_image[cat_id][0], 3)}',
-                    fontdict={'fontsize': 20, 'fontweight': 'bold'},
-                )
+
+                if bounds is not None:
+                    min_rec, max_rec = bounds[0], bounds[1]
+                    if _rec_per_image[cat_id][0] < min_rec:
+                        continue
+                else:
+                    ax.text(
+                        x=_rec_per_image[cat_id][0], y=_prec_accuracy[cat_id][0],
+                        s=f' R = {np.round(_rec_per_image[cat_id][0], 3)}',
+                        fontdict={'fontsize': 20, 'fontweight': 'bold'},
+                    )
+
                 ins.hlines(
                     y=_prec_accuracy[cat_id][0],
-                    xmin=np.min(all_rec),
-                    xmax=np.max(all_rec),
+                    xmin=.6,
+                    xmax=1.,
                     linestyles='dashed',
                     colors=c,
                 )
@@ -253,8 +265,8 @@ def generate_bootstrap_count_curves(
     ax.set_position([box.x0, box.y0, box.width * 0.8, box.height])
 
     ax.legend(
-        loc='center left', bbox_to_anchor=(.95, .75),
-        fancybox=True, shadow=True, ncol=1, fontsize=25,
+        loc='lower left', bbox_to_anchor=(.65, .1),
+        fancybox=True, shadow=True, ncol=1, fontsize=30,
     )
 
     ax.set_title(plot_title, fontdict={'fontsize': 35})
@@ -268,9 +280,13 @@ def generate_bootstrap_count_curves(
     ax.tick_params(axis='both', which='major', labelsize=30)
     ins.tick_params(axis='both', which='major', labelsize=20)
 
-    ax.set_ylim(bottom=0.05, top=1.02)
-    ax.set_xlim(min_rec, 1.0)
-
+    if bounds is not None:
+        x_min, x_max, _, _ = bounds
+        ax.set_xlim([x_min, x_max])
+    else:
+        ax.set_xlim([.7, 1.0])
+        ax.set_ylim(bottom=0.05, top=1.02)
+    fig.tight_layout()
     fig.savefig(plot_output_path, dpi=150)
 
     os.remove('/tmp/tmp_bootstrap_gt.json')
